pub struct ParseInput<'a>(/* private fields */);Implementations
Sourceimpl<'a> ParseInput<'a>
impl<'a> ParseInput<'a>
pub fn new(input: &'a str) -> Self
Sourcepub fn peek_n(&self, n: usize) -> &'a str
pub fn peek_n(&self, n: usize) -> &'a str
Returns the next n characters without advancing the input
Sourcepub fn pop_to_next(&mut self, c: char) -> Option<&str>
pub fn pop_to_next(&mut self, c: char) -> Option<&str>
Returns the next word and advances the input
Sourcepub fn match_next(&mut self, string: &str) -> bool
pub fn match_next(&mut self, string: &str) -> bool
Matches the case-insensitive string and advances the input if it matches
Sourcepub fn skip_whitespace(&mut self)
pub fn skip_whitespace(&mut self)
Skip all whitespace at the front of the input
Sourcepub fn into_inner(self) -> &'a str
pub fn into_inner(self) -> &'a str
Set the inner string
pub fn len(&self) -> usize